@@ -10,7 +10,7 @@ def parse_args(path, col_to_apply_on, value, result_path):
     if type(path) is pd.DataFrame() or pl.DataFrame():
         df = pl.DataFrame(path)
     elif not is_url(path) and not file_exists(path):
-        raise ValueError(f'{path} does not exist or it is a directory')
+        raise ValueError(f'{path} does not exist or it is a directory (not file)')
     elif ext_str(result_path) not in _supported_types_:
         raise ValueError(f'output file type: {ext_str(result_path)} not supported yet, supported types {_supported_types_}')
     else:
